;+
; NAME: 
; 				INVERSE_POLAR_FFT
;
;
; PURPOSE: 
; 				process the inverse polar fft 
;
; CALLING: 
; 				inverse_polar_fft, f, m, max_i, real, ima, ff
;
; INPUTS: 
;				real, ima --- real and imagiary part of the polar fourier transform
; 				
; KEYWORD:
;				PolarFFT_CutOffParam --- cut-off parameter in the approximation
; 				(the larger it is the better approximation is)
; 			  	Max_i --- number of iteration in the inversion
;	
; OUTPUT: 
; 				ff --- image resulting from an inverse polar fft 
;
; HISTORY:
;	Written: Sandrine Pires Sept. 2009.
;-
;-------------------------------------------------------------------------------
pro inverse_polar_fft, real, ima, ff, PolarFFT_CutOffParam=PolarFFT_CutOffParam, Max_iter = Max_iter, Name=Name

if keyword_set(PolarFFT_CutOffParam) then  m = PolarFFT_CutOffParam else m = 8
if keyword_set(Max_iter) then max_i = Max_iter else max_i = 10.
a = systime(1)

IN_FITSFILE_RE = gettmpfilename()
IN_FITSFILE_IM = gettmpfilename()
IN_DATFILE_RE = Name+'_polarfft_r.dat'
IN_DATFILE_IM = Name+'_polarfft_i.dat'
OUT_DATFILE = Name+'_inv_polarfft.dat'
OUT_FITSFILE = gettmpfilename()


writefits, IN_FITSFILE_RE, real
writefits, IN_FITSFILE_IM, ima

sz =size(real)
R = sz[1]
T = sz[2]
N= T/3.

fits2dat, file_fits=IN_FITSFILE_RE, filefits, file_dat=IN_DATFILE_RE
fits2dat, file_fits=IN_FITSFILE_IM, filefits, file_dat=IN_DATFILE_IM
com = 'cea_inverse_polar_fft' +' ' +string(N)+' ' +string(T)+' ' +string(R)+' '+string(m)+' '+string(max_i)+' '+string(Name)
spawn, com

dat2fits, file_dat=OUT_DATFILE ,filefits,file_fits=OUT_FITSFILE

ff = readfits(OUT_FITSFILE)

delete, IN_FITSFILE_RE
delete, IN_FITSFILE_IM
delete, IN_DATFILE_RE
delete, IN_DATFILE_IM
delete, OUT_DATFILE
delete, OUT_FITSFILE

print, 'time =', systime(1)-a
end
