;+
; NAME: 
;       POLFFT_BISPEC_EQ
;
; PURPOSE: 
;       Calculate the isotropic equilateral bispectrum 
;       
; CALLING:
;	bispec= polfft_bispec_eq(imag, x=x, PolarFFT\_CutOffParam=PolarFFT) 
;
; INPUTS:
;	imag --- input image
;
; KEYWORD:
;	PolarFFT\_CutOffParam : cut-off parameter in the polar FFT approximation
;	(the larger it is the better approximation is)
;       Name : Name output file
;
; OUTPUT KEYWORDS:
;	x ---  x-axis (frequencies)
;
; OUTPUTS:
;       bispec --- bispectrum
;
; EXTERNAL CALLS:
;       cea_polar_fft (C++ program) 
;
;-----------------------------------------------------------------------
function polfft_bispec_eq, imag, x=x,PolarFFT_CutOffParam=PolarFFT_CutOffParam, Name=Name
b = systime(1)

if not keyword_set(PolarFFT_CutOffParam) then PolarFFT_CutOffParam = 8

;run polar fft
print, 'THE TIME TO PROCESS AN EXACT POWER SPECTRUM IS MUCH MORE LONGER'
polar_fft, imag, real, ima, PolarFFT_CutOffParam=PolarFFT_CutOffParam, Name=Name

;set dimensions
sz =size(imag)
n1 = sz[1]
n2 = sz[2]
if (n1 ne n2) then print, "map must be square !"
sz =size(real)
R = sz[1]
T = sz[2]

;reform real and ima
Nr = (R/2.)
Nt = T*2
re_imag = fltarr(Nr, Nt)
im_imag = fltarr(Nr, Nt)
re_imag(*, 0: T-1) = real(n1*3./4.: n1*3./2-1, *) 
im_imag(*, 0: T-1) = ima(n1*3./4.: n1*3./2-1, *) 
re_imag(*, T: 2*T-1) = reverse(real(1:n1*3./4., *)) 
im_imag(*, T: 2*T-1) = reverse(ima(1:n1*3./4., *))

;equilateral bispectrum calculation
re_bispec = fltarr(Nr)
im_bispec = fltarr(Nr)
som = fltarr(Nr)
for i = 0, Nr-1 do begin
  for j = 0, Nt/3.-1 do begin
    ii = i
    jj = j
    a1 = re_imag(ii,jj)
    b1 = im_imag(ii,jj)
    a2 = re_imag(ii,jj+Nt/3.)
    b2 = im_imag(ii,jj+Nt/3.)
    a3 = re_imag(ii,jj+(2.*Nt)/3.)
    b3 = im_imag(ii,jj+(2.*Nt)/3.)
    ;B(k1)B(k2)B(k3)* = B(k1)B(k2)B(-k3) = (a1+ib1)(a2+ib2)(a3+ib3)
    ;re_bispec(ii) = re_bispec(ii) +a1*a2*a3 +a1*b2*b3 +b1*a2*b3 -b1*b2*a3
    re_bispec(ii) = re_bispec(ii) +a1*a2*a3 -a1*b2*b3 -b1*a2*b3 -b1*b2*a3
    im_bispec(ii) = im_bispec(ii) -b1*b2*b3 +b1*a2*a3 +a1*b2*a3 +a1*a2*b3
    som(ii) = som(ii) + 1
  endfor
endfor 
bispec=complex(re_bispec, im_bispec)
;bispec = bispec/(float(som)*n1^3)
bispec = bispec/(float(som)*n1^2)
x=indgen(Nr)/ float(R)
print, 'time =', systime(1)-b
return, bispec
end
