;+
; NAME: 
;				POLFFT_BL_EQ
;
; PURPOSE: 
;				to plot bispectrum (l^4 * bl)/(2*!pi)^2
;
; CALLING:
;				polfft_bl_eq(imag, psize_arcmin, l=l, PolarFFT_CutOffParam =PolarFFT_CutOffParam
;				, plot=plot, overplot=overplot)
;
; INPUTS: 
;				imag --- input imag
;				psize_arcmin --- pixel size in arcmin	
;	
; OUTPUT: 
; 				cl --- cl of harmonic transform
; 				l --- l frequencies
;	      
; KEYWORD
; 				plot --- to plot the power spectrum
; 				overplot --- to overplot a power spectrum
;                               Name : Name output file
;
; HISTORY:
;	Written: Sandrine Pires Jan 2009.
;-
;-------------------------------------------------------------------------------
function polfft_bl_eq, imag, field_deg, l=l,  PolarFFT_CutOffParam =PolarFFT_CutOffParam, plot=plot, overplot=overplot, Name=Name

sz = size(imag)
n1 = sz[1]
n2 = sz[2]

if n1 eq n2 then begin
  N = n1
	field_rad = (field_deg*!pi)/180.
endif else begin
  print, "n1 non equal to n2"
endelse

bispec = polfft_bispec_eq(imag, x=x, PolarFFT_CutOffParam =PolarFFT_CutOffParam), Name=Name


;l normalisation
l = (2.*x*!pi*float(N))/float(field_rad)
plot, l

;cl normalisation that verify : \sigma = \integral{l*cl/2*!pi} dl
;bl = sqrt(re(bispec)^2 + im(bispec)^2)*(field_rad^4)/float(N)^4
bl = sqrt(re(bispec)^2 + im(bispec)^2)*(field_rad^4)/float(N)^4
		
if keyword_set(plot) then begin
  plot, l, (l^4*(bl))/(2*!pi)^2, /xtype, /ytype, xtitle='l',$
  ytitle='l^4.Bl/2!7p!3^2', $
  xrange=[1e1, 1e5] ,yrange=[1e-10, 1e-3]
endif
if keyword_set(overplot) then begin
  oplot, l, (l^4*bl)/(2*!pi)^2
endif 
return, bl

end
 
	 
