;+
; NAME: 
;				POLFFT_BL_ISO
;
; PURPOSE: 
;				to plot a power spectrum cl(l+1)l/2*!pi = f(l) in its units [in rad]
;
; CALLING:
;				polfft_bl_iso, map, field_deg, cb, l, iso = 30, /plot
;
; INPUTS: 
;				map --- map
;				field_deg --- field in deg	
;	
; OUTPUT: 
; 			bl --- bl of harmonic transform
; 			l --- l frequencies
;	      
; KEYWORD
; 			plot --- to plot the power spectrum
; 			overplot --- to overplot a power spectrum
; 			iso --- theta angle in degrees to define isoscele triangle
; 			(equilateral iso : 120)
;                       Name : Name output file
;
; HISTORY:
;	Written: Sandrine Pires March 2009
;-
;-------------------------------------------------------------------------------
function polfft_bl_iso, map, iso=iso, field_deg, l=l,  PolarFFT_CutOffParam =PolarFFT_CutOffParam, plot=plot, overplot=overplot, Name=Name

sz = size(map)
n1 = sz[1]
n2 = sz[2]

if n1 eq n2 then begin
  N = n1
	field_rad = (field_deg*!pi)/180.
endif else begin
  print, "n1 non equal to n2"
endelse

bispec = polfft_bispec_iso(map, x=x, iso=iso, PolarFFT_CutOffParam =PolarFFT_CutOffParam), Name=Name

;l normalisation
l = (2.*x*!pi*float(N))/float(field_rad)

;cl normalisation that verify : \sigma = \integral{l*cl/2*!pi} dl
;bl = sqrt(re(bispec)^2 + im(bispec)^2)*(field_rad^4)/float(N)^4
bl = sqrt(re(bispec)^2 + im(bispec)^2)*(field_rad^4)/float(N)^4
		
if keyword_set(plot) then begin
  plot, l, (l^4*(bl))/(2*!pi)^2, /xtype, /ytype, xtitle='l',$
  ytitle='l^4.Bl/2!7p!3^2', $
  xrange=[1e1, 1e5] ,yrange=[1e-10, 1e-3]
endif
if keyword_set(overplot) then begin
  oplot, l, (l^4*bl)/(2*!pi)^2, color=4
endif 

return, bl

end
 
	 
