;+
; NAME: 
;	POLFFT_CL
;
; PURPOSE: 
;	Calculate and plot the Cl
;       
; CALLING:
;	cl= polfft_cl(imag, l=l, PolarFFT\_CutOffParam=PolarFFT, 
;	psize_arcmin=psize_arcmin,  plot=plot)
;
; INPUTS:
;       imag --- input image
;
; KEYWORD:
;	PolarFFT\_CutOffParam : cut-off parameter in the polar FFT
;	approximation (the larger it is the better approximation is)
;	psize_arcmin : pixel size in arcmin
;	plot : plot
;       Name : Name output file
;
; OUTPUT KEYWORDS:
;       x --- x-axis (frequencies)
;
; OUTPUTS:
;       Cl --- power spectrum
;
; EXTERNAL CALLS:
;       cea_polar_fft (C++ program) ;
;-----------------------------------------------------------------------

function polfft_cl, imag, l=l, PolarFFT_CutOffParam=PolarFFT_CutOffParam, psize_arcmin=psize_arcmin, plot=plot, Name=Name
powspec = -1
if not keyword_set(PolarFFT_CutOffParam) then PolarFFT_CutOffParam = 8
sz = size(imag)
n1 = sz[1]
n2 = sz[2]
if n1 eq n2 then begin
  N = n1
endif else begin
  print, "ERROR: Nx non equal to ny"
  goto, DONE
endelse


; By default the pixel size is the PLANCK pixel size (nside=2048) in arc minute
if not keyword_set(psize_arcmin) then psize_arcmin =  1.31063

; Size of the field in degree
field_deg = float(N) * psize_arcmin / 60.
field_rad = (field_deg*!pi)/180.

; Surface of the field in radian^2
surf_field_rad = field_rad^2.

; Compute the power spectrum (x output will be in [0,0.5])
powspec =  polfft_powspec(imag, x=x, PolarFFT_CutOffParam=PolarFFT_CutOffParam), Name=Name

; Compute the Cl from the power spectrum
;l normalisation
factor1 = (2.*!pi*float(n1))/ float(field_rad)
l = x*factor1

;cl normalisation that verify : \sigma = \integral{l*cl/2*!pi} dl
cl = powspec*(surf_field_rad)/float(N)^2

if keyword_set(plot) then plt_cl, cl, l

DONE:

return, cl

end

