;+
; NAME: 
;	POLFFT_POWSPEC
;
; PURPOSE: 
;	Calculate the power spectrum 
;       
; CALLING:
;	powspec= polfft_powspec(imag, x=x, PolarFFT\_CutOffParam=PolarFFT)
;
; INPUTS:
;       Imag --- input image
;
; KEYWORD:
;	PolarFFT\_CutOffParam : cut-off parameter in the polar FFT approximation
;	(the larger it is the better approximation is)
;       Name : Name output file
;
; OUTPUT KEYWORDS:
;       x --- x-axis (frequencies)
;
; OUTPUTS:
;       powspec --- power spectrum
;
; EXTERNAL CALLS:
;       cea_polar_fft (C++ program) ;
;-----------------------------------------------------------------------
function polfft_powspec, imag, x=x, PolarFFT_CutOffParam=PolarFFT_CutOffParam, Name=Name
; b = systime(1)

if not keyword_set(PolarFFT_CutOffParam) then PolarFFT_CutOffParam = 8
sz = size(imag)
n1 = sz[1]
n2 = sz[2]

; Compute the Polar FFT
polar_fft, imag, real, ima, PolarFFT_CutOffParam=PolarFFT_CutOffParam, Name=Name
sz =size(real)
R = sz[1]  ; R = number of radius
T = sz[2]  ; T = number of angles
N = T/3    ; N = input image size

; Compute the power spectrum
spec = fltarr(R/2 + 1)
som = fltarr(R/2 + 1)
for i = 0, R-2 do begin
  for j = 0, T-2 do begin
	   ii = abs(i - R/2)
		 som(ii) = som(ii) + 1
     spec(ii) = spec(ii) + real(i,j)^2 + ima(i,j)^2
  endfor
endfor 

powspec = spec/(float(som)*N^2)

; x-abscisse, between [0,0.5]
x=indgen(R/2 + 1)/ float(R)

; print, 'time =', systime(1)-b

return, powspec
end

